//-----------------------------------------------------------------------------
// Title      : bsp_ub053_mk3_fastfat_r
//-----------------------------------------------------------------------------
// Funktion   : SD-Card Test [READ] (mit FastFat16-Treiber)
// Schaltung  : myAVR MK3
//-----------------------------------------------------------------------------
// Prozessor  : ATMega2560
// Takt       : 16 MHz
// Sprache    : C
// Date       : 05.07.2012
// Version    : 1.0
// Autor      : UB
//-----------------------------------------------------------------------------
#define F_CPU 16000000
#include <avr/io.h>
#include <ub_mk3_2560/MK3_2560_LCD.h>
#include <ub_mk3_2560/MK3_2560_FASTFAT16.h>

//-----------------------------------------------------------------------------
// Hinweis : Quick-Jumper Port-C+A muss gesetzt sein
// - testet ob eine SD-Karte eingelegt ist
// - liest ein File aus (muss einen String enthalten)
// - zeigt bei Erfolg eine OK-Meldung an
//   und die ersten 20 Zeichen vom File
//-----------------------------------------------------------------------------

int main (void)
{
	unsigned int n;
	FFR_Status_t check;
	uint8_t buffer[30]; // puffer fr das auslesen
	
	MK3_INIT_LCD();					// init des LCD
	
	MK3_LCD_CLEAR();				// LCD loeschen
	MK3_LCD_LIGHT(true);			// beleuchtung einschalten
	
	MK3_LCD_STRING_AT(0,0,"FASTFAT16 READ");
	MK3_LCD_STRING_AT(0,16,"suche SD-Karte:");
	
	check=MK3_SD_READ_FILE_IN_ROOT("ff_file.txt");
	
	if(check==SDR_READ_OK) {
		MK3_LCD_STRING_AT(0,24,"File gefunden");
		// 20 Zeichen vom inhalt auslesen
		fat_read_file(MK3_SD.file, buffer, 20);
		// Inhalt auf dem Display anzeigen
		MK3_LCD_STRING_AT(0,40,"Inhalt=");
		MK3_LCD_SETCURSOR(0,48);
		for(n=0;n<20;n++) {
		  lcdPrintAsc(buffer[n]);
		}
		// File schliessen
		MK3_SD_CLOSE_FILE();
	}
	else if(check==SDR_NO_CARD) {
		MK3_LCD_STRING_AT(0,24,"Err...keine Karte");
	}
	else if(check==SDR_FILE_NOT_FOUND) {
		MK3_LCD_STRING_AT(0,24,"Err...File not found");
	}
	else {
		MK3_LCD_STRING_AT(0,24,"Err...Dateifehler");
	}
	

	while (true)
	{
	
	}
	return 0;
}
//-----------------------------------------------------------------------------






